@@ -6,8 +6,7 @@
 //  See http://www.boost.org/libs/test for the library home page.
 
 // Boost.Test
-// only one file should define BOOST_TEST_MAIN/BOOST_TEST_MODULE
-#define BOOST_TEST_MODULE Unit_test_example_09_2
+#define BOOST_TEST_MODULE Unit_test_example_09
 #include <boost/test/included/unit_test.hpp>
 
 // STL
@@ -15,17 +14,17 @@
 
 //____________________________________________________________________________//
 
-struct MyConfig2 {
-    MyConfig2() { std::cout << "global setup part2\n"; }
-    ~MyConfig2() { std::cout << "global teardown part2\n"; }
+struct MyConfig {
+    MyConfig() { std::cout << "global setup part1\n"; }
+    ~MyConfig() { std::cout << "global teardown part1\n"; }
 };
 
-// structure MyConfig2 is used as a global fixture. You could have any number of global fxtures
-BOOST_GLOBAL_FIXTURE( MyConfig2 )
+// structure MyConfig is used as a global fixture - it's invoked pre and post any testing is performed
+BOOST_TEST_GLOBAL_FIXTURE( MyConfig );
 
 //____________________________________________________________________________//
 
-BOOST_AUTO_TEST_CASE( my_test2 )
+BOOST_AUTO_TEST_CASE( my_test1 )
 {
     BOOST_CHECK( true );
 }
