@@ -1,11 +1,14 @@
-import sys
-import pytest
 import subprocess
+import sys
+from distutils.spawn import find_executable
+
+import pytest
+
 from pytest_cpp import error
 from pytest_cpp.boost import BoostTestFacade
-from pytest_cpp.error import CppTestFailure, CppFailureRepr
+from pytest_cpp.catch2 import Catch2Facade
+from pytest_cpp.error import CppFailureRepr, CppTestFailure
 from pytest_cpp.google import GoogleTestFacade
-from distutils.spawn import find_executable
 
 
 def assert_outcomes(result, expected_outcomes):
@@ -49,6 +52,7 @@ def dummy_failure():
         (BoostTestFacade(), "boost_success", ["boost_success"]),
         (BoostTestFacade(), "boost_error", ["boost_error"]),
         (BoostTestFacade(), "boost_fixture_setup_error", ["boost_fixture_setup_error"]),
+        (Catch2Facade(), "catch2_success", ["Factorials are computed"]),
     ],
 )
 def test_list_tests(facade, name, expected, exes):
@@ -61,6 +65,7 @@ def test_list_tests(facade, name, expected, exes):
     [
         (GoogleTestFacade(), "gtest", "boost_success"),
         (BoostTestFacade(), "boost_success", "gtest"),
+        (Catch2Facade(), "catch2_success", "gtest"),
     ],
 )
 def test_is_test_suite(facade, name, other_name, exes, tmpdir):
@@ -75,6 +80,7 @@ def test_is_test_suite(facade, name, other_name, exes, tmpdir):
     [
         (GoogleTestFacade(), "gtest", "FooTest.test_success"),
         (BoostTestFacade(), "boost_success", "<unused>"),
+        (Catch2Facade(), "catch2_success", "Factorials are computed"),
     ],
 )
 def test_success(facade, name, test_id, exes):
@@ -171,7 +177,7 @@ def test_boost_fixture_setup_error(exes):
     fail1 = failures[0]
     colors = ("red", "bold")
     ((line, obtained_colors),) = fail1.get_lines()
-    assert line.startswith("Test setup error")
+    assert line == "std::runtime_error: This is a global fixture init failure"
     assert obtained_colors == colors
     assert fail1.get_file_reference() == ("unknown location", 0)
 
@@ -281,7 +287,7 @@ def test_cpp_files_option(testdir, exes):
     exes.get("gtest")
 
     result = testdir.runpytest("--collect-only")
-    result.stdout.fnmatch_lines("* no tests ran *")
+    result.stdout.fnmatch_lines("* no tests *")
 
     testdir.makeini(
         """
@@ -310,7 +316,7 @@ def test_cpp_ignore_py_files(testdir, exes):
     )
 
     result = testdir.runpytest("--collect-only")
-    result.stdout.fnmatch_lines("* no tests ran *")
+    result.stdout.fnmatch_lines("* no tests *")
 
     result = testdir.runpytest("--collect-only", "-o", "cpp_ignore_py_files=False")
     result.stdout.fnmatch_lines("*CppFile cpptest_success.py*")
@@ -534,6 +540,25 @@ def test_cpp_verbose(testdir, exes):
     )
 
 
+def test_catch2_failure(exes):
+    facade = Catch2Facade()
+    failures, _ = facade.run_test(exes.get("catch2_failure"), "Factorials are computed")
+    assert len(failures) == 1
+
+    fail1 = failures[0]
+    colors = ("red", "bold")
+    assert fail1.get_lines() == [
+        ("Expected: ", colors),
+        ("          Factorial(1) == 0", colors),
+        ("        ", colors),
+        ("Actual: ", colors),
+        ("          1 == 0", colors),
+        ("        ", colors),
+    ]
+
+    assert fail1.get_file_reference() == ("catch2_failure.cpp", 9)
+
+
 class TestError:
     def test_get_whitespace(self):
         assert error.get_left_whitespace("  foo") == "  "
